
======
Tricks
======


* `What is batch size in neural network? <https://stats.stackexchange.com/questions/153531/what-is-batch-size-in-neural-network>`_
* `深度机器学习中的batch的大小对学习效果有何影响？ <https://www.zhihu.com/question/32673260>`_




